@@ -19,8 +19,9 @@ from LivestockCV.core.apply_mask import apply_mask
 from LivestockCV.core.crop import crop
 from LivestockCV.core.invert import invert
 from LivestockCV.core import roi
-from LivestockCV.core import thresholding
+from LivestockCV.core import threshold
 from LivestockCV.core import gaussian_blur
+from LivestockCV.core import analyze_color
 # add new functions to end of lists
 
 # Auto versioning
@@ -28,4 +29,4 @@ from ._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
 
-__all__ = ['fatal_error', 'Params', 'Outputs', 'deprecation_warning', 'print_image', 'plot_image', 'color_palette', 'rgb2gray', 'rgb2gray_hsv', 'rgb2gray_lab', 'transform', 'apply_mask', 'crop', 'invert', 'roi', 'thresholding', 'gaussian_blur']
+__all__ = ['fatal_error', 'Params', 'Outputs', 'deprecation_warning', 'print_image', 'plot_image', 'color_palette', 'rgb2gray', 'rgb2gray_hsv', 'rgb2gray_lab', 'transform', 'apply_mask', 'crop', 'invert', 'roi', 'threshold', 'gaussian_blur', 'analyze_color']
